#!/bin/bash
# Porter Libby

LEASE_FILE="/var/lib/dhcp/dhcpd.leases"
CURRENT_TIME=$(date +%s)

parse_leases() {
  while read -r line; do
    case "$line" in
      lease*)
        # Extract IP address
        IP=$(echo "$line" | awk '{print $2}')
        ;;
      ends*)
        LEASE_END=$(echo "$line" | awk '{print $3 " " $4}' | sed 's/;$//')
        LEASE_END_EPOCH=$(date -d "$LEASE_END" +%s)
        ;;
      client-hostname*)
        HOSTNAME=$(echo "$line" | awk -F '"' '{print $2}')
        ;;
      "}")
        if [[ -n "$LEASE_END_EPOCH" ]]; then
          REMAINING=$((LEASE_END_EPOCH - CURRENT_TIME))
          if (( REMAINING < 0 )); then
            REMAINING=0
          fi
          echo "$HOSTNAME - $IP (${REMAINING}s remaining)"
        fi
        IP=""
        LEASE_END=""
        LEASE_END_EPOCH=""
        HOSTNAME=""
        ;;
    esac
  done < "$LEASE_FILE"
}

while true ; do
  tput clear # to clear the screen
  echo "DHCP Leases - $(date)";
  echo "";
  parse_leases;
  sleep 5
done
